@@ -22,7 +22,7 @@
 
 __name__ = 'pylast'
 __version__ = '0.3'
-__revision__ = "$Revision: 199 $"
+__revision__ = "$Revision: 201 $"
 __doc__ = 'A Python interface to Last.fm'
 __author__ = 'Amr Hassan'
 __copyright__ = "Copyright (C) 2008-2009  Amr Hassan"
@@ -2123,10 +2123,10 @@ class User(_BaseObject):
 		
 		return list
 	
-	def get_loved_tracks(self):
-		"""Returns the last 50 tracks loved by this user. """
+	def get_loved_tracks(self, limit=50, page=1):
+		"""Returns the loved tracks by this user """
 		
-		doc = self._request('user.getLovedTracks', True)
+		doc = self._request('user.getLovedTracks', True, {"limit": str(limit), "page": str(page)})
 		
 		list = []
 		for track in doc.getElementsByTagName('track'):
@@ -3210,9 +3210,9 @@ class Scrobbler(object):
 			mbid: MusicBrainz ID.
 		"""
 		
-		params = {"s": self._get_session_id(), "a[0]": artist, "t[0]": title,
+		params = {"s": self._get_session_id(), "a[0]": artist.encode("utf-8"), "t[0]": title.encode("utf-8"),
 			"i[0]": str(time_started), "o[0]": source, "r[0]": mode, "l[0]": str(duration),
-			"b[0]": album, "n[0]": track_number, "m[0]": mbid}
+			"b[0]": album.encode("utf-8"), "n[0]": track_number, "m[0]": mbid}
 		
 		response = _ScrobblerRequest(self.submissions_url, params).execute()
 		info(artist + " - " + title + " was scrobbled")
